# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.keyword_plan_common_pb2 import (
    KeywordPlanHistoricalMetrics as google___ads___googleads___v2___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics,
)

from google.ads.google_ads.v2.proto.resources.keyword_plan_pb2 import (
    KeywordPlan as google___ads___googleads___v2___resources___keyword_plan_pb2___KeywordPlan,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from google.rpc.status_pb2 import (
    Status as google___rpc___status_pb2___Status,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetKeywordPlanRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetKeywordPlanRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class MutateKeywordPlansRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    partial_failure = ... # type: bool
    validate_only = ... # type: bool

    @property
    def operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[KeywordPlanOperation]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        operations : typing___Optional[typing___Iterable[KeywordPlanOperation]] = None,
        partial_failure : typing___Optional[bool] = None,
        validate_only : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateKeywordPlansRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"operations",u"partial_failure",u"validate_only"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"operations",b"operations",u"partial_failure",b"partial_failure",u"validate_only",b"validate_only"]) -> None: ...

class KeywordPlanOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    remove = ... # type: typing___Text

    @property
    def update_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...

    @property
    def create(self) -> google___ads___googleads___v2___resources___keyword_plan_pb2___KeywordPlan: ...

    @property
    def update(self) -> google___ads___googleads___v2___resources___keyword_plan_pb2___KeywordPlan: ...

    def __init__(self,
        *,
        update_mask : typing___Optional[google___protobuf___field_mask_pb2___FieldMask] = None,
        create : typing___Optional[google___ads___googleads___v2___resources___keyword_plan_pb2___KeywordPlan] = None,
        update : typing___Optional[google___ads___googleads___v2___resources___keyword_plan_pb2___KeywordPlan] = None,
        remove : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"create",u"operation",u"remove",u"update",u"update_mask"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",u"operation",u"remove",u"update",u"update_mask"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation",u"remove",b"remove",u"update",b"update",u"update_mask",b"update_mask"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation",u"remove",b"remove",u"update",b"update",u"update_mask",b"update_mask"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"operation",b"operation"]) -> typing_extensions___Literal["create","update","remove"]: ...

class MutateKeywordPlansResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[MutateKeywordPlansResult]: ...

    def __init__(self,
        *,
        partial_failure_error : typing___Optional[google___rpc___status_pb2___Status] = None,
        results : typing___Optional[typing___Iterable[MutateKeywordPlansResult]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateKeywordPlansResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",u"results"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error",u"results",b"results"]) -> None: ...

class MutateKeywordPlansResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateKeywordPlansResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class GenerateForecastMetricsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    keyword_plan = ... # type: typing___Text

    def __init__(self,
        *,
        keyword_plan : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateForecastMetricsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_plan"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_plan",b"keyword_plan"]) -> None: ...

class GenerateForecastMetricsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def campaign_forecasts(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[KeywordPlanCampaignForecast]: ...

    @property
    def ad_group_forecasts(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[KeywordPlanAdGroupForecast]: ...

    @property
    def keyword_forecasts(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[KeywordPlanKeywordForecast]: ...

    def __init__(self,
        *,
        campaign_forecasts : typing___Optional[typing___Iterable[KeywordPlanCampaignForecast]] = None,
        ad_group_forecasts : typing___Optional[typing___Iterable[KeywordPlanAdGroupForecast]] = None,
        keyword_forecasts : typing___Optional[typing___Iterable[KeywordPlanKeywordForecast]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateForecastMetricsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_forecasts",u"campaign_forecasts",u"keyword_forecasts"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_forecasts",b"ad_group_forecasts",u"campaign_forecasts",b"campaign_forecasts",u"keyword_forecasts",b"keyword_forecasts"]) -> None: ...

class KeywordPlanCampaignForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def keyword_plan_campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def campaign_forecast(self) -> ForecastMetrics: ...

    def __init__(self,
        *,
        keyword_plan_campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        campaign_forecast : typing___Optional[ForecastMetrics] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanCampaignForecast: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_forecast",u"keyword_plan_campaign"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_forecast",u"keyword_plan_campaign"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_forecast",b"campaign_forecast",u"keyword_plan_campaign",b"keyword_plan_campaign"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_forecast",b"campaign_forecast",u"keyword_plan_campaign",b"keyword_plan_campaign"]) -> None: ...

class KeywordPlanAdGroupForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def keyword_plan_ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group_forecast(self) -> ForecastMetrics: ...

    def __init__(self,
        *,
        keyword_plan_ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group_forecast : typing___Optional[ForecastMetrics] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanAdGroupForecast: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_forecast",u"keyword_plan_ad_group"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_forecast",u"keyword_plan_ad_group"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_forecast",b"ad_group_forecast",u"keyword_plan_ad_group",b"keyword_plan_ad_group"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_forecast",b"ad_group_forecast",u"keyword_plan_ad_group",b"keyword_plan_ad_group"]) -> None: ...

class KeywordPlanKeywordForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def keyword_plan_ad_group_keyword(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def keyword_forecast(self) -> ForecastMetrics: ...

    def __init__(self,
        *,
        keyword_plan_ad_group_keyword : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        keyword_forecast : typing___Optional[ForecastMetrics] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanKeywordForecast: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"keyword_forecast",u"keyword_plan_ad_group_keyword"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_forecast",u"keyword_plan_ad_group_keyword"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"keyword_forecast",b"keyword_forecast",u"keyword_plan_ad_group_keyword",b"keyword_plan_ad_group_keyword"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_forecast",b"keyword_forecast",u"keyword_plan_ad_group_keyword",b"keyword_plan_ad_group_keyword"]) -> None: ...

class ForecastMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def ctr(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_cpc(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        ctr : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_cpc : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        clicks : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ForecastMetrics: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"average_cpc",u"clicks",u"cost_micros",u"ctr",u"impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"average_cpc",u"clicks",u"cost_micros",u"ctr",u"impressions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"average_cpc",b"average_cpc",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"ctr",b"ctr",u"impressions",b"impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"average_cpc",b"average_cpc",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"ctr",b"ctr",u"impressions",b"impressions"]) -> None: ...

class GenerateHistoricalMetricsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    keyword_plan = ... # type: typing___Text

    def __init__(self,
        *,
        keyword_plan : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateHistoricalMetricsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_plan"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_plan",b"keyword_plan"]) -> None: ...

class GenerateHistoricalMetricsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def metrics(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[KeywordPlanKeywordHistoricalMetrics]: ...

    def __init__(self,
        *,
        metrics : typing___Optional[typing___Iterable[KeywordPlanKeywordHistoricalMetrics]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateHistoricalMetricsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"metrics"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"metrics",b"metrics"]) -> None: ...

class KeywordPlanKeywordHistoricalMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def search_query(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def keyword_metrics(self) -> google___ads___googleads___v2___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics: ...

    def __init__(self,
        *,
        search_query : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        keyword_metrics : typing___Optional[google___ads___googleads___v2___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanKeywordHistoricalMetrics: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"keyword_metrics",u"search_query"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_metrics",u"search_query"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"keyword_metrics",b"keyword_metrics",u"search_query",b"search_query"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_metrics",b"keyword_metrics",u"search_query",b"search_query"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.placement_type_pb2 import (
    PlacementTypeEnum as google___ads___googleads___v2___enums___placement_type_pb2___PlacementTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GroupPlacementView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    placement_type = ... # type: google___ads___googleads___v2___enums___placement_type_pb2___PlacementTypeEnum.PlacementType

    @property
    def placement(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def display_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def target_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        placement : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        display_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        target_url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        placement_type : typing___Optional[google___ads___googleads___v2___enums___placement_type_pb2___PlacementTypeEnum.PlacementType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GroupPlacementView: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"display_name",u"placement",u"target_url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"display_name",u"placement",u"placement_type",u"resource_name",u"target_url"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"display_name",b"display_name",u"placement",b"placement",u"target_url",b"target_url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"display_name",b"display_name",u"placement",b"placement",u"placement_type",b"placement_type",u"resource_name",b"resource_name",u"target_url",b"target_url"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.google_ads_field_category_pb2 import (
    GoogleAdsFieldCategoryEnum as google___ads___googleads___v2___enums___google_ads_field_category_pb2___GoogleAdsFieldCategoryEnum,
)

from google.ads.google_ads.v2.proto.enums.google_ads_field_data_type_pb2 import (
    GoogleAdsFieldDataTypeEnum as google___ads___googleads___v2___enums___google_ads_field_data_type_pb2___GoogleAdsFieldDataTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GoogleAdsField(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    category = ... # type: google___ads___googleads___v2___enums___google_ads_field_category_pb2___GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategory
    data_type = ... # type: google___ads___googleads___v2___enums___google_ads_field_data_type_pb2___GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def selectable(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def filterable(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def sortable(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def selectable_with(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def attribute_resources(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def metrics(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def segments(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def enum_values(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def type_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def is_repeated(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        category : typing___Optional[google___ads___googleads___v2___enums___google_ads_field_category_pb2___GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategory] = None,
        selectable : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        filterable : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        sortable : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        selectable_with : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        attribute_resources : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        metrics : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        segments : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        enum_values : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        data_type : typing___Optional[google___ads___googleads___v2___enums___google_ads_field_data_type_pb2___GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType] = None,
        type_url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        is_repeated : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GoogleAdsField: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"filterable",u"is_repeated",u"name",u"selectable",u"sortable",u"type_url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"attribute_resources",u"category",u"data_type",u"enum_values",u"filterable",u"is_repeated",u"metrics",u"name",u"resource_name",u"segments",u"selectable",u"selectable_with",u"sortable",u"type_url"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"filterable",b"filterable",u"is_repeated",b"is_repeated",u"name",b"name",u"selectable",b"selectable",u"sortable",b"sortable",u"type_url",b"type_url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"attribute_resources",b"attribute_resources",u"category",b"category",u"data_type",b"data_type",u"enum_values",b"enum_values",u"filterable",b"filterable",u"is_repeated",b"is_repeated",u"metrics",b"metrics",u"name",b"name",u"resource_name",b"resource_name",u"segments",b"segments",u"selectable",b"selectable",u"selectable_with",b"selectable_with",u"sortable",b"sortable",u"type_url",b"type_url"]) -> None: ...



# Stubs for google.ads.google_ads.v2.services.transports.ad_group_ad_service_grpc_transport (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class AdGroupAdServiceGrpcTransport:
    def __init__(self, channel: Optional[Any] = ..., credentials: Optional[Any] = ..., address: str = ...) -> None: ...
    @classmethod
    def create_channel(cls, address: str = ..., credentials: Optional[Any] = ..., **kwargs: Any): ...
    @property
    def channel(self): ...
    @property
    def get_ad_group_ad(self): ...
    @property
    def mutate_ad_group_ads(self): ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class OperationAccessDeniedErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class OperationAccessDeniedError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> OperationAccessDeniedErrorEnum.OperationAccessDeniedError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[OperationAccessDeniedErrorEnum.OperationAccessDeniedError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, OperationAccessDeniedErrorEnum.OperationAccessDeniedError]]: ...
        UNSPECIFIED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 0)
        UNKNOWN = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 1)
        ACTION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 2)
        CREATE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 3)
        REMOVE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 4)
        UPDATE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 5)
        MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 6)
        OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 7)
        CREATE_AS_REMOVED_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 8)
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 9)
        OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 10)
        MUTATE_NOT_PERMITTED_FOR_CUSTOMER = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 11)
    UNSPECIFIED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 0)
    UNKNOWN = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 1)
    ACTION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 2)
    CREATE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 3)
    REMOVE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 4)
    UPDATE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 5)
    MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 6)
    OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 7)
    CREATE_AS_REMOVED_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 8)
    OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 9)
    OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 10)
    MUTATE_NOT_PERMITTED_FOR_CUSTOMER = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 11)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> OperationAccessDeniedErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.criteria_pb2 import (
    KeywordInfo as google___ads___googleads___v1___common___criteria_pb2___KeywordInfo,
    MobileAppCategoryInfo as google___ads___googleads___v1___common___criteria_pb2___MobileAppCategoryInfo,
    MobileApplicationInfo as google___ads___googleads___v1___common___criteria_pb2___MobileApplicationInfo,
    PlacementInfo as google___ads___googleads___v1___common___criteria_pb2___PlacementInfo,
    YouTubeChannelInfo as google___ads___googleads___v1___common___criteria_pb2___YouTubeChannelInfo,
    YouTubeVideoInfo as google___ads___googleads___v1___common___criteria_pb2___YouTubeVideoInfo,
)

from google.ads.google_ads.v1.proto.enums.criterion_type_pb2 import (
    CriterionTypeEnum as google___ads___googleads___v1___enums___criterion_type_pb2___CriterionTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class SharedCriterion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    type = ... # type: google___ads___googleads___v1___enums___criterion_type_pb2___CriterionTypeEnum.CriterionType

    @property
    def shared_set(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def keyword(self) -> google___ads___googleads___v1___common___criteria_pb2___KeywordInfo: ...

    @property
    def youtube_video(self) -> google___ads___googleads___v1___common___criteria_pb2___YouTubeVideoInfo: ...

    @property
    def youtube_channel(self) -> google___ads___googleads___v1___common___criteria_pb2___YouTubeChannelInfo: ...

    @property
    def placement(self) -> google___ads___googleads___v1___common___criteria_pb2___PlacementInfo: ...

    @property
    def mobile_app_category(self) -> google___ads___googleads___v1___common___criteria_pb2___MobileAppCategoryInfo: ...

    @property
    def mobile_application(self) -> google___ads___googleads___v1___common___criteria_pb2___MobileApplicationInfo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        shared_set : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        criterion_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        type : typing___Optional[google___ads___googleads___v1___enums___criterion_type_pb2___CriterionTypeEnum.CriterionType] = None,
        keyword : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___KeywordInfo] = None,
        youtube_video : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___YouTubeVideoInfo] = None,
        youtube_channel : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___YouTubeChannelInfo] = None,
        placement : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___PlacementInfo] = None,
        mobile_app_category : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___MobileAppCategoryInfo] = None,
        mobile_application : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___MobileApplicationInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SharedCriterion: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"criterion",u"criterion_id",u"keyword",u"mobile_app_category",u"mobile_application",u"placement",u"shared_set",u"youtube_channel",u"youtube_video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"criterion",u"criterion_id",u"keyword",u"mobile_app_category",u"mobile_application",u"placement",u"resource_name",u"shared_set",u"type",u"youtube_channel",u"youtube_video"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"keyword",b"keyword",u"mobile_app_category",b"mobile_app_category",u"mobile_application",b"mobile_application",u"placement",b"placement",u"shared_set",b"shared_set",u"youtube_channel",b"youtube_channel",u"youtube_video",b"youtube_video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"keyword",b"keyword",u"mobile_app_category",b"mobile_app_category",u"mobile_application",b"mobile_application",u"placement",b"placement",u"resource_name",b"resource_name",u"shared_set",b"shared_set",u"type",b"type",u"youtube_channel",b"youtube_channel",u"youtube_video",b"youtube_video"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"criterion",b"criterion"]) -> typing_extensions___Literal["keyword","youtube_video","youtube_channel","placement","mobile_app_category","mobile_application"]: ...



# Stubs for google.ads.google_ads.v1.proto.services.ad_group_simulation_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class AdGroupSimulationServiceStub:
    GetAdGroupSimulation: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupSimulationServiceServicer:
    def GetAdGroupSimulation(self, request: Any, context: Any) -> None: ...

def add_AdGroupSimulationServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class PromotionPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PromotionPlaceholderField(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> PromotionPlaceholderFieldEnum.PromotionPlaceholderField: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[PromotionPlaceholderFieldEnum.PromotionPlaceholderField]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, PromotionPlaceholderFieldEnum.PromotionPlaceholderField]]: ...
        UNSPECIFIED = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 0)
        UNKNOWN = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 1)
        PROMOTION_TARGET = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 2)
        DISCOUNT_MODIFIER = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 3)
        PERCENT_OFF = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 4)
        MONEY_AMOUNT_OFF = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 5)
        PROMOTION_CODE = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 6)
        ORDERS_OVER_AMOUNT = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 7)
        PROMOTION_START = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 8)
        PROMOTION_END = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 9)
        OCCASION = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 10)
        FINAL_URLS = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 11)
        FINAL_MOBILE_URLS = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 12)
        TRACKING_URL = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 13)
        LANGUAGE = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 14)
        FINAL_URL_SUFFIX = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 15)
    UNSPECIFIED = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 0)
    UNKNOWN = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 1)
    PROMOTION_TARGET = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 2)
    DISCOUNT_MODIFIER = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 3)
    PERCENT_OFF = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 4)
    MONEY_AMOUNT_OFF = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 5)
    PROMOTION_CODE = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 6)
    ORDERS_OVER_AMOUNT = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 7)
    PROMOTION_START = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 8)
    PROMOTION_END = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 9)
    OCCASION = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 10)
    FINAL_URLS = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 11)
    FINAL_MOBILE_URLS = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 12)
    TRACKING_URL = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 13)
    LANGUAGE = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 14)
    FINAL_URL_SUFFIX = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 15)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PromotionPlaceholderFieldEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class DomainCategory(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def category(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def domain(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def coverage_fraction(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def category_rank(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def has_children(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def recommended_cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        category : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        language_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        domain : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        coverage_fraction : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        category_rank : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        has_children : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        recommended_cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> DomainCategory: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"campaign",u"category",u"category_rank",u"coverage_fraction",u"domain",u"has_children",u"language_code",u"recommended_cpc_bid_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign",u"category",u"category_rank",u"coverage_fraction",u"domain",u"has_children",u"language_code",u"recommended_cpc_bid_micros",u"resource_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"campaign",b"campaign",u"category",b"category",u"category_rank",b"category_rank",u"coverage_fraction",b"coverage_fraction",u"domain",b"domain",u"has_children",b"has_children",u"language_code",b"language_code",u"recommended_cpc_bid_micros",b"recommended_cpc_bid_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign",b"campaign",u"category",b"category",u"category_rank",b"category_rank",u"coverage_fraction",b"coverage_fraction",u"domain",b"domain",u"has_children",b"has_children",u"language_code",b"language_code",u"recommended_cpc_bid_micros",b"recommended_cpc_bid_micros",u"resource_name",b"resource_name"]) -> None: ...



import grpc  # type: ignore
from google.ads.google_ads.v1.services.transports.geo_target_constant_service_grpc_transport import GeoTargetConstantServiceGrpcTransport
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar, Text
from google.ads.google_ads.v1.proto.resources.geo_target_constant_pb2 import GeoTargetConstant
from google.protobuf.wrappers_pb2 import StringValue

from google.ads.google_ads.v1.proto.services.geo_target_constant_service_pb2 import SuggestGeoTargetConstantsResponse, \
    SuggestGeoTargetConstantsRequest
from typing_extensions import TypedDict


class StringValueDict(TypedDict):
    value: Text


class GeoTargetConstantServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> GeoTargetConstantServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> GeoTargetConstantServiceClient: ...
    @classmethod
    def geo_target_constant_path(cls, geo_target_constant: Any): ...
    transport: Union[GeoTargetConstantServiceGrpcTransport, Callable[[Credentials, type], GeoTargetConstantServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[GeoTargetConstantServiceGrpcTransport, Callable[[Credentials, type], GeoTargetConstantServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def get_geo_target_constant(self, resource_name: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> GeoTargetConstant: ...
    def suggest_geo_target_constants(self, locale: Union[StringValueDict, StringValue], country_code: Union[StringValueDict, StringValue], location_names: Optional[Union[Dict[Any, Any], SuggestGeoTargetConstantsRequest.LocationNames]] = ..., geo_targets: Optional[Union[Dict[Any, Any], SuggestGeoTargetConstantsRequest.GeoTargets]] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> SuggestGeoTargetConstantsResponse: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class UserListSizeRangeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class UserListSizeRange(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> UserListSizeRangeEnum.UserListSizeRange: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[UserListSizeRangeEnum.UserListSizeRange]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, UserListSizeRangeEnum.UserListSizeRange]]: ...
        UNSPECIFIED = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 0)
        UNKNOWN = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 1)
        LESS_THAN_FIVE_HUNDRED = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 2)
        LESS_THAN_ONE_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 3)
        ONE_THOUSAND_TO_TEN_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 4)
        TEN_THOUSAND_TO_FIFTY_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 5)
        FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 6)
        ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 7)
        THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 8)
        FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 9)
        ONE_MILLION_TO_TWO_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 10)
        TWO_MILLION_TO_THREE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 11)
        THREE_MILLION_TO_FIVE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 12)
        FIVE_MILLION_TO_TEN_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 13)
        TEN_MILLION_TO_TWENTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 14)
        TWENTY_MILLION_TO_THIRTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 15)
        THIRTY_MILLION_TO_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 16)
        OVER_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 17)
    UNSPECIFIED = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 0)
    UNKNOWN = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 1)
    LESS_THAN_FIVE_HUNDRED = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 2)
    LESS_THAN_ONE_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 3)
    ONE_THOUSAND_TO_TEN_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 4)
    TEN_THOUSAND_TO_FIFTY_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 5)
    FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 6)
    ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 7)
    THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 8)
    FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 9)
    ONE_MILLION_TO_TWO_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 10)
    TWO_MILLION_TO_THREE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 11)
    THREE_MILLION_TO_FIVE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 12)
    FIVE_MILLION_TO_TEN_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 13)
    TEN_MILLION_TO_TWENTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 14)
    TWENTY_MILLION_TO_THIRTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 15)
    THIRTY_MILLION_TO_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 16)
    OVER_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 17)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListSizeRangeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class Value(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    boolean_value = ... # type: bool
    int64_value = ... # type: int
    float_value = ... # type: float
    double_value = ... # type: float
    string_value = ... # type: typing___Text

    def __init__(self,
        *,
        boolean_value : typing___Optional[bool] = None,
        int64_value : typing___Optional[int] = None,
        float_value : typing___Optional[float] = None,
        double_value : typing___Optional[float] = None,
        string_value : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Value: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"boolean_value",u"double_value",u"float_value",u"int64_value",u"string_value",u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"boolean_value",u"double_value",u"float_value",u"int64_value",u"string_value",u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"boolean_value",b"boolean_value",u"double_value",b"double_value",u"float_value",b"float_value",u"int64_value",b"int64_value",u"string_value",b"string_value",u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"boolean_value",b"boolean_value",u"double_value",b"double_value",u"float_value",b"float_value",u"int64_value",b"int64_value",u"string_value",b"string_value",u"value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"value",b"value"]) -> typing_extensions___Literal["boolean_value","int64_value","float_value","double_value","string_value"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.served_asset_field_type_pb2 import (
    ServedAssetFieldTypeEnum as google___ads___googleads___v2___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdTextAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    pinned_field = ... # type: google___ads___googleads___v2___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum.ServedAssetFieldType

    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        pinned_field : typing___Optional[google___ads___googleads___v2___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum.ServedAssetFieldType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdTextAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"pinned_field",u"text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"text",b"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"pinned_field",b"pinned_field",u"text",b"text"]) -> None: ...

class AdImageAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def asset(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        asset : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdImageAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> None: ...

class AdVideoAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def asset(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        asset : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdVideoAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> None: ...

class AdMediaBundleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def asset(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        asset : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdMediaBundleAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.customer_match_upload_key_type_pb2 import (
    CustomerMatchUploadKeyTypeEnum as google___ads___googleads___v2___enums___customer_match_upload_key_type_pb2___CustomerMatchUploadKeyTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_combined_rule_operator_pb2 import (
    UserListCombinedRuleOperatorEnum as google___ads___googleads___v2___enums___user_list_combined_rule_operator_pb2___UserListCombinedRuleOperatorEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_crm_data_source_type_pb2 import (
    UserListCrmDataSourceTypeEnum as google___ads___googleads___v2___enums___user_list_crm_data_source_type_pb2___UserListCrmDataSourceTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_date_rule_item_operator_pb2 import (
    UserListDateRuleItemOperatorEnum as google___ads___googleads___v2___enums___user_list_date_rule_item_operator_pb2___UserListDateRuleItemOperatorEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_logical_rule_operator_pb2 import (
    UserListLogicalRuleOperatorEnum as google___ads___googleads___v2___enums___user_list_logical_rule_operator_pb2___UserListLogicalRuleOperatorEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_number_rule_item_operator_pb2 import (
    UserListNumberRuleItemOperatorEnum as google___ads___googleads___v2___enums___user_list_number_rule_item_operator_pb2___UserListNumberRuleItemOperatorEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_prepopulation_status_pb2 import (
    UserListPrepopulationStatusEnum as google___ads___googleads___v2___enums___user_list_prepopulation_status_pb2___UserListPrepopulationStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_rule_type_pb2 import (
    UserListRuleTypeEnum as google___ads___googleads___v2___enums___user_list_rule_type_pb2___UserListRuleTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_string_rule_item_operator_pb2 import (
    UserListStringRuleItemOperatorEnum as google___ads___googleads___v2___enums___user_list_string_rule_item_operator_pb2___UserListStringRuleItemOperatorEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class SimilarUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def seed_user_list(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        seed_user_list : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SimilarUserListInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"seed_user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"seed_user_list"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"seed_user_list",b"seed_user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"seed_user_list",b"seed_user_list"]) -> None: ...

class CrmBasedUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    upload_key_type = ... # type: google___ads___googleads___v2___enums___customer_match_upload_key_type_pb2___CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType
    data_source_type = ... # type: google___ads___googleads___v2___enums___user_list_crm_data_source_type_pb2___UserListCrmDataSourceTypeEnum.UserListCrmDataSourceType

    @property
    def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        app_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        upload_key_type : typing___Optional[google___ads___googleads___v2___enums___customer_match_upload_key_type_pb2___CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType] = None,
        data_source_type : typing___Optional[google___ads___googleads___v2___enums___user_list_crm_data_source_type_pb2___UserListCrmDataSourceTypeEnum.UserListCrmDataSourceType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CrmBasedUserListInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"app_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"app_id",u"data_source_type",u"upload_key_type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id",u"data_source_type",b"data_source_type",u"upload_key_type",b"upload_key_type"]) -> None: ...

class UserListRuleInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    rule_type = ... # type: google___ads___googleads___v2___enums___user_list_rule_type_pb2___UserListRuleTypeEnum.UserListRuleType

    @property
    def rule_item_groups(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[UserListRuleItemGroupInfo]: ...

    def __init__(self,
        *,
        rule_type : typing___Optional[google___ads___googleads___v2___enums___user_list_rule_type_pb2___UserListRuleTypeEnum.UserListRuleType] = None,
        rule_item_groups : typing___Optional[typing___Iterable[UserListRuleItemGroupInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListRuleInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"rule_item_groups",u"rule_type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"rule_item_groups",b"rule_item_groups",u"rule_type",b"rule_type"]) -> None: ...

class UserListRuleItemGroupInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def rule_items(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[UserListRuleItemInfo]: ...

    def __init__(self,
        *,
        rule_items : typing___Optional[typing___Iterable[UserListRuleItemInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListRuleItemGroupInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"rule_items"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"rule_items",b"rule_items"]) -> None: ...

class UserListRuleItemInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def number_rule_item(self) -> UserListNumberRuleItemInfo: ...

    @property
    def string_rule_item(self) -> UserListStringRuleItemInfo: ...

    @property
    def date_rule_item(self) -> UserListDateRuleItemInfo: ...

    def __init__(self,
        *,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        number_rule_item : typing___Optional[UserListNumberRuleItemInfo] = None,
        string_rule_item : typing___Optional[UserListStringRuleItemInfo] = None,
        date_rule_item : typing___Optional[UserListDateRuleItemInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListRuleItemInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"date_rule_item",u"name",u"number_rule_item",u"rule_item",u"string_rule_item"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"date_rule_item",u"name",u"number_rule_item",u"rule_item",u"string_rule_item"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"date_rule_item",b"date_rule_item",u"name",b"name",u"number_rule_item",b"number_rule_item",u"rule_item",b"rule_item",u"string_rule_item",b"string_rule_item"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"date_rule_item",b"date_rule_item",u"name",b"name",u"number_rule_item",b"number_rule_item",u"rule_item",b"rule_item",u"string_rule_item",b"string_rule_item"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"rule_item",b"rule_item"]) -> typing_extensions___Literal["number_rule_item","string_rule_item","date_rule_item"]: ...

class UserListDateRuleItemInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator = ... # type: google___ads___googleads___v2___enums___user_list_date_rule_item_operator_pb2___UserListDateRuleItemOperatorEnum.UserListDateRuleItemOperator

    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def offset_in_days(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        operator : typing___Optional[google___ads___googleads___v2___enums___user_list_date_rule_item_operator_pb2___UserListDateRuleItemOperatorEnum.UserListDateRuleItemOperator] = None,
        value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        offset_in_days : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListDateRuleItemInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"offset_in_days",u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"offset_in_days",u"operator",u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"offset_in_days",b"offset_in_days",u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"offset_in_days",b"offset_in_days",u"operator",b"operator",u"value",b"value"]) -> None: ...

class UserListNumberRuleItemInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator = ... # type: google___ads___googleads___v2___enums___user_list_number_rule_item_operator_pb2___UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator

    @property
    def value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    def __init__(self,
        *,
        operator : typing___Optional[google___ads___googleads___v2___enums___user_list_number_rule_item_operator_pb2___UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator] = None,
        value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListNumberRuleItemInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operator",u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operator",b"operator",u"value",b"value"]) -> None: ...

class UserListStringRuleItemInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator = ... # type: google___ads___googleads___v2___enums___user_list_string_rule_item_operator_pb2___UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator

    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        operator : typing___Optional[google___ads___googleads___v2___enums___user_list_string_rule_item_operator_pb2___UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator] = None,
        value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListStringRuleItemInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operator",u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operator",b"operator",u"value",b"value"]) -> None: ...

class CombinedRuleUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    rule_operator = ... # type: google___ads___googleads___v2___enums___user_list_combined_rule_operator_pb2___UserListCombinedRuleOperatorEnum.UserListCombinedRuleOperator

    @property
    def left_operand(self) -> UserListRuleInfo: ...

    @property
    def right_operand(self) -> UserListRuleInfo: ...

    def __init__(self,
        *,
        left_operand : typing___Optional[UserListRuleInfo] = None,
        right_operand : typing___Optional[UserListRuleInfo] = None,
        rule_operator : typing___Optional[google___ads___googleads___v2___enums___user_list_combined_rule_operator_pb2___UserListCombinedRuleOperatorEnum.UserListCombinedRuleOperator] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CombinedRuleUserListInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"left_operand",u"right_operand"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"left_operand",u"right_operand",u"rule_operator"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"left_operand",b"left_operand",u"right_operand",b"right_operand"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"left_operand",b"left_operand",u"right_operand",b"right_operand",u"rule_operator",b"rule_operator"]) -> None: ...

class DateSpecificRuleUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def rule(self) -> UserListRuleInfo: ...

    @property
    def start_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def end_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        rule : typing___Optional[UserListRuleInfo] = None,
        start_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        end_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> DateSpecificRuleUserListInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"end_date",u"rule",u"start_date"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"end_date",u"rule",u"start_date"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"end_date",b"end_date",u"rule",b"rule",u"start_date",b"start_date"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"end_date",b"end_date",u"rule",b"rule",u"start_date",b"start_date"]) -> None: ...

class ExpressionRuleUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def rule(self) -> UserListRuleInfo: ...

    def __init__(self,
        *,
        rule : typing___Optional[UserListRuleInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ExpressionRuleUserListInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"rule"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"rule"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"rule",b"rule"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"rule",b"rule"]) -> None: ...

class RuleBasedUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    prepopulation_status = ... # type: google___ads___googleads___v2___enums___user_list_prepopulation_status_pb2___UserListPrepopulationStatusEnum.UserListPrepopulationStatus

    @property
    def combined_rule_user_list(self) -> CombinedRuleUserListInfo: ...

    @property
    def date_specific_rule_user_list(self) -> DateSpecificRuleUserListInfo: ...

    @property
    def expression_rule_user_list(self) -> ExpressionRuleUserListInfo: ...

    def __init__(self,
        *,
        prepopulation_status : typing___Optional[google___ads___googleads___v2___enums___user_list_prepopulation_status_pb2___UserListPrepopulationStatusEnum.UserListPrepopulationStatus] = None,
        combined_rule_user_list : typing___Optional[CombinedRuleUserListInfo] = None,
        date_specific_rule_user_list : typing___Optional[DateSpecificRuleUserListInfo] = None,
        expression_rule_user_list : typing___Optional[ExpressionRuleUserListInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RuleBasedUserListInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"combined_rule_user_list",u"date_specific_rule_user_list",u"expression_rule_user_list",u"rule_based_user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"combined_rule_user_list",u"date_specific_rule_user_list",u"expression_rule_user_list",u"prepopulation_status",u"rule_based_user_list"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"combined_rule_user_list",b"combined_rule_user_list",u"date_specific_rule_user_list",b"date_specific_rule_user_list",u"expression_rule_user_list",b"expression_rule_user_list",u"rule_based_user_list",b"rule_based_user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"combined_rule_user_list",b"combined_rule_user_list",u"date_specific_rule_user_list",b"date_specific_rule_user_list",u"expression_rule_user_list",b"expression_rule_user_list",u"prepopulation_status",b"prepopulation_status",u"rule_based_user_list",b"rule_based_user_list"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"rule_based_user_list",b"rule_based_user_list"]) -> typing_extensions___Literal["combined_rule_user_list","date_specific_rule_user_list","expression_rule_user_list"]: ...

class LogicalUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def rules(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[UserListLogicalRuleInfo]: ...

    def __init__(self,
        *,
        rules : typing___Optional[typing___Iterable[UserListLogicalRuleInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LogicalUserListInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"rules"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"rules",b"rules"]) -> None: ...

class UserListLogicalRuleInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator = ... # type: google___ads___googleads___v2___enums___user_list_logical_rule_operator_pb2___UserListLogicalRuleOperatorEnum.UserListLogicalRuleOperator

    @property
    def rule_operands(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[LogicalUserListOperandInfo]: ...

    def __init__(self,
        *,
        operator : typing___Optional[google___ads___googleads___v2___enums___user_list_logical_rule_operator_pb2___UserListLogicalRuleOperatorEnum.UserListLogicalRuleOperator] = None,
        rule_operands : typing___Optional[typing___Iterable[LogicalUserListOperandInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListLogicalRuleInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"operator",u"rule_operands"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"operator",b"operator",u"rule_operands",b"rule_operands"]) -> None: ...

class LogicalUserListOperandInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def user_list(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        user_list : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LogicalUserListOperandInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"user_list"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"user_list",b"user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"user_list",b"user_list"]) -> None: ...

class BasicUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def actions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[UserListActionInfo]: ...

    def __init__(self,
        *,
        actions : typing___Optional[typing___Iterable[UserListActionInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BasicUserListInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"actions"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"actions",b"actions"]) -> None: ...

class UserListActionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def remarketing_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        remarketing_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListActionInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_action",u"remarketing_action",u"user_list_action"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_action",u"remarketing_action",u"user_list_action"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_action",b"conversion_action",u"remarketing_action",b"remarketing_action",u"user_list_action",b"user_list_action"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_action",b"conversion_action",u"remarketing_action",b"remarketing_action",u"user_list_action",b"user_list_action"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"user_list_action",b"user_list_action"]) -> typing_extensions___Literal["conversion_action","remarketing_action"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FeedMappingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FeedMappingError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FeedMappingErrorEnum.FeedMappingError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FeedMappingErrorEnum.FeedMappingError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FeedMappingErrorEnum.FeedMappingError]]: ...
        UNSPECIFIED = typing___cast(FeedMappingErrorEnum.FeedMappingError, 0)
        UNKNOWN = typing___cast(FeedMappingErrorEnum.FeedMappingError, 1)
        INVALID_PLACEHOLDER_FIELD = typing___cast(FeedMappingErrorEnum.FeedMappingError, 2)
        INVALID_CRITERION_FIELD = typing___cast(FeedMappingErrorEnum.FeedMappingError, 3)
        INVALID_PLACEHOLDER_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 4)
        INVALID_CRITERION_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 5)
        NO_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(FeedMappingErrorEnum.FeedMappingError, 7)
        FEED_ATTRIBUTE_TYPE_MISMATCH = typing___cast(FeedMappingErrorEnum.FeedMappingError, 8)
        CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = typing___cast(FeedMappingErrorEnum.FeedMappingError, 9)
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 10)
        MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 11)
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = typing___cast(FeedMappingErrorEnum.FeedMappingError, 12)
        MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = typing___cast(FeedMappingErrorEnum.FeedMappingError, 13)
        UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(FeedMappingErrorEnum.FeedMappingError, 14)
        LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = typing___cast(FeedMappingErrorEnum.FeedMappingError, 15)
        CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = typing___cast(FeedMappingErrorEnum.FeedMappingError, 16)
        INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = typing___cast(FeedMappingErrorEnum.FeedMappingError, 17)
        INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 18)
    UNSPECIFIED = typing___cast(FeedMappingErrorEnum.FeedMappingError, 0)
    UNKNOWN = typing___cast(FeedMappingErrorEnum.FeedMappingError, 1)
    INVALID_PLACEHOLDER_FIELD = typing___cast(FeedMappingErrorEnum.FeedMappingError, 2)
    INVALID_CRITERION_FIELD = typing___cast(FeedMappingErrorEnum.FeedMappingError, 3)
    INVALID_PLACEHOLDER_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 4)
    INVALID_CRITERION_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 5)
    NO_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(FeedMappingErrorEnum.FeedMappingError, 7)
    FEED_ATTRIBUTE_TYPE_MISMATCH = typing___cast(FeedMappingErrorEnum.FeedMappingError, 8)
    CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = typing___cast(FeedMappingErrorEnum.FeedMappingError, 9)
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 10)
    MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 11)
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = typing___cast(FeedMappingErrorEnum.FeedMappingError, 12)
    MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = typing___cast(FeedMappingErrorEnum.FeedMappingError, 13)
    UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(FeedMappingErrorEnum.FeedMappingError, 14)
    LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = typing___cast(FeedMappingErrorEnum.FeedMappingError, 15)
    CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = typing___cast(FeedMappingErrorEnum.FeedMappingError, 16)
    INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = typing___cast(FeedMappingErrorEnum.FeedMappingError, 17)
    INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = typing___cast(FeedMappingErrorEnum.FeedMappingError, 18)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedMappingErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FunctionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FunctionError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FunctionErrorEnum.FunctionError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FunctionErrorEnum.FunctionError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FunctionErrorEnum.FunctionError]]: ...
        UNSPECIFIED = typing___cast(FunctionErrorEnum.FunctionError, 0)
        UNKNOWN = typing___cast(FunctionErrorEnum.FunctionError, 1)
        INVALID_FUNCTION_FORMAT = typing___cast(FunctionErrorEnum.FunctionError, 2)
        DATA_TYPE_MISMATCH = typing___cast(FunctionErrorEnum.FunctionError, 3)
        INVALID_CONJUNCTION_OPERANDS = typing___cast(FunctionErrorEnum.FunctionError, 4)
        INVALID_NUMBER_OF_OPERANDS = typing___cast(FunctionErrorEnum.FunctionError, 5)
        INVALID_OPERAND_TYPE = typing___cast(FunctionErrorEnum.FunctionError, 6)
        INVALID_OPERATOR = typing___cast(FunctionErrorEnum.FunctionError, 7)
        INVALID_REQUEST_CONTEXT_TYPE = typing___cast(FunctionErrorEnum.FunctionError, 8)
        INVALID_FUNCTION_FOR_CALL_PLACEHOLDER = typing___cast(FunctionErrorEnum.FunctionError, 9)
        INVALID_FUNCTION_FOR_PLACEHOLDER = typing___cast(FunctionErrorEnum.FunctionError, 10)
        INVALID_OPERAND = typing___cast(FunctionErrorEnum.FunctionError, 11)
        MISSING_CONSTANT_OPERAND_VALUE = typing___cast(FunctionErrorEnum.FunctionError, 12)
        INVALID_CONSTANT_OPERAND_VALUE = typing___cast(FunctionErrorEnum.FunctionError, 13)
        INVALID_NESTING = typing___cast(FunctionErrorEnum.FunctionError, 14)
        MULTIPLE_FEED_IDS_NOT_SUPPORTED = typing___cast(FunctionErrorEnum.FunctionError, 15)
        INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA = typing___cast(FunctionErrorEnum.FunctionError, 16)
        INVALID_ATTRIBUTE_NAME = typing___cast(FunctionErrorEnum.FunctionError, 17)
    UNSPECIFIED = typing___cast(FunctionErrorEnum.FunctionError, 0)
    UNKNOWN = typing___cast(FunctionErrorEnum.FunctionError, 1)
    INVALID_FUNCTION_FORMAT = typing___cast(FunctionErrorEnum.FunctionError, 2)
    DATA_TYPE_MISMATCH = typing___cast(FunctionErrorEnum.FunctionError, 3)
    INVALID_CONJUNCTION_OPERANDS = typing___cast(FunctionErrorEnum.FunctionError, 4)
    INVALID_NUMBER_OF_OPERANDS = typing___cast(FunctionErrorEnum.FunctionError, 5)
    INVALID_OPERAND_TYPE = typing___cast(FunctionErrorEnum.FunctionError, 6)
    INVALID_OPERATOR = typing___cast(FunctionErrorEnum.FunctionError, 7)
    INVALID_REQUEST_CONTEXT_TYPE = typing___cast(FunctionErrorEnum.FunctionError, 8)
    INVALID_FUNCTION_FOR_CALL_PLACEHOLDER = typing___cast(FunctionErrorEnum.FunctionError, 9)
    INVALID_FUNCTION_FOR_PLACEHOLDER = typing___cast(FunctionErrorEnum.FunctionError, 10)
    INVALID_OPERAND = typing___cast(FunctionErrorEnum.FunctionError, 11)
    MISSING_CONSTANT_OPERAND_VALUE = typing___cast(FunctionErrorEnum.FunctionError, 12)
    INVALID_CONSTANT_OPERAND_VALUE = typing___cast(FunctionErrorEnum.FunctionError, 13)
    INVALID_NESTING = typing___cast(FunctionErrorEnum.FunctionError, 14)
    MULTIPLE_FEED_IDS_NOT_SUPPORTED = typing___cast(FunctionErrorEnum.FunctionError, 15)
    INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA = typing___cast(FunctionErrorEnum.FunctionError, 16)
    INVALID_ATTRIBUTE_NAME = typing___cast(FunctionErrorEnum.FunctionError, 17)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FunctionErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.matching_function_context_type_pb2 import (
    MatchingFunctionContextTypeEnum as google___ads___googleads___v1___enums___matching_function_context_type_pb2___MatchingFunctionContextTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.matching_function_operator_pb2 import (
    MatchingFunctionOperatorEnum as google___ads___googleads___v1___enums___matching_function_operator_pb2___MatchingFunctionOperatorEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class MatchingFunction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator = ... # type: google___ads___googleads___v1___enums___matching_function_operator_pb2___MatchingFunctionOperatorEnum.MatchingFunctionOperator

    @property
    def function_string(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def left_operands(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[Operand]: ...

    @property
    def right_operands(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[Operand]: ...

    def __init__(self,
        *,
        function_string : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        operator : typing___Optional[google___ads___googleads___v1___enums___matching_function_operator_pb2___MatchingFunctionOperatorEnum.MatchingFunctionOperator] = None,
        left_operands : typing___Optional[typing___Iterable[Operand]] = None,
        right_operands : typing___Optional[typing___Iterable[Operand]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MatchingFunction: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"function_string"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"function_string",u"left_operands",u"operator",u"right_operands"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"function_string",b"function_string"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"function_string",b"function_string",u"left_operands",b"left_operands",u"operator",b"operator",u"right_operands",b"right_operands"]) -> None: ...

class Operand(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ConstantOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def string_value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def long_value(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def boolean_value(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

        @property
        def double_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

        def __init__(self,
            *,
            string_value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            long_value : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            boolean_value : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
            double_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Operand.ConstantOperand: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"boolean_value",u"constant_operand_value",u"double_value",u"long_value",u"string_value"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"boolean_value",u"constant_operand_value",u"double_value",u"long_value",u"string_value"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"boolean_value",b"boolean_value",u"constant_operand_value",b"constant_operand_value",u"double_value",b"double_value",u"long_value",b"long_value",u"string_value",b"string_value"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"boolean_value",b"boolean_value",u"constant_operand_value",b"constant_operand_value",u"double_value",b"double_value",u"long_value",b"long_value",u"string_value",b"string_value"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions___Literal[u"constant_operand_value",b"constant_operand_value"]) -> typing_extensions___Literal["string_value","long_value","boolean_value","double_value"]: ...

    class FeedAttributeOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def feed_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def feed_attribute_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            feed_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            feed_attribute_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Operand.FeedAttributeOperand: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"feed_attribute_id",u"feed_id"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"feed_attribute_id",u"feed_id"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"feed_attribute_id",b"feed_attribute_id",u"feed_id",b"feed_id"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"feed_attribute_id",b"feed_attribute_id",u"feed_id",b"feed_id"]) -> None: ...

    class FunctionOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def matching_function(self) -> MatchingFunction: ...

        def __init__(self,
            *,
            matching_function : typing___Optional[MatchingFunction] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Operand.FunctionOperand: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"matching_function"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"matching_function"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"matching_function",b"matching_function"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"matching_function",b"matching_function"]) -> None: ...

    class RequestContextOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        context_type = ... # type: google___ads___googleads___v1___enums___matching_function_context_type_pb2___MatchingFunctionContextTypeEnum.MatchingFunctionContextType

        def __init__(self,
            *,
            context_type : typing___Optional[google___ads___googleads___v1___enums___matching_function_context_type_pb2___MatchingFunctionContextTypeEnum.MatchingFunctionContextType] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Operand.RequestContextOperand: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"context_type"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"context_type",b"context_type"]) -> None: ...


    @property
    def constant_operand(self) -> Operand.ConstantOperand: ...

    @property
    def feed_attribute_operand(self) -> Operand.FeedAttributeOperand: ...

    @property
    def function_operand(self) -> Operand.FunctionOperand: ...

    @property
    def request_context_operand(self) -> Operand.RequestContextOperand: ...

    def __init__(self,
        *,
        constant_operand : typing___Optional[Operand.ConstantOperand] = None,
        feed_attribute_operand : typing___Optional[Operand.FeedAttributeOperand] = None,
        function_operand : typing___Optional[Operand.FunctionOperand] = None,
        request_context_operand : typing___Optional[Operand.RequestContextOperand] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Operand: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"constant_operand",u"feed_attribute_operand",u"function_argument_operand",u"function_operand",u"request_context_operand"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"constant_operand",u"feed_attribute_operand",u"function_argument_operand",u"function_operand",u"request_context_operand"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"constant_operand",b"constant_operand",u"feed_attribute_operand",b"feed_attribute_operand",u"function_argument_operand",b"function_argument_operand",u"function_operand",b"function_operand",u"request_context_operand",b"request_context_operand"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"constant_operand",b"constant_operand",u"feed_attribute_operand",b"feed_attribute_operand",u"function_argument_operand",b"function_argument_operand",u"function_operand",b"function_operand",u"request_context_operand",b"request_context_operand"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"function_argument_operand",b"function_argument_operand"]) -> typing_extensions___Literal["constant_operand","feed_attribute_operand","function_operand","request_context_operand"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class MutateErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class MutateError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> MutateErrorEnum.MutateError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[MutateErrorEnum.MutateError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, MutateErrorEnum.MutateError]]: ...
        UNSPECIFIED = typing___cast(MutateErrorEnum.MutateError, 0)
        UNKNOWN = typing___cast(MutateErrorEnum.MutateError, 1)
        RESOURCE_NOT_FOUND = typing___cast(MutateErrorEnum.MutateError, 3)
        ID_EXISTS_IN_MULTIPLE_MUTATES = typing___cast(MutateErrorEnum.MutateError, 7)
        INCONSISTENT_FIELD_VALUES = typing___cast(MutateErrorEnum.MutateError, 8)
        MUTATE_NOT_ALLOWED = typing___cast(MutateErrorEnum.MutateError, 9)
        RESOURCE_NOT_IN_GOOGLE_ADS = typing___cast(MutateErrorEnum.MutateError, 10)
        RESOURCE_ALREADY_EXISTS = typing___cast(MutateErrorEnum.MutateError, 11)
    UNSPECIFIED = typing___cast(MutateErrorEnum.MutateError, 0)
    UNKNOWN = typing___cast(MutateErrorEnum.MutateError, 1)
    RESOURCE_NOT_FOUND = typing___cast(MutateErrorEnum.MutateError, 3)
    ID_EXISTS_IN_MULTIPLE_MUTATES = typing___cast(MutateErrorEnum.MutateError, 7)
    INCONSISTENT_FIELD_VALUES = typing___cast(MutateErrorEnum.MutateError, 8)
    MUTATE_NOT_ALLOWED = typing___cast(MutateErrorEnum.MutateError, 9)
    RESOURCE_NOT_IN_GOOGLE_ADS = typing___cast(MutateErrorEnum.MutateError, 10)
    RESOURCE_ALREADY_EXISTS = typing___cast(MutateErrorEnum.MutateError, 11)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
